"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getRestField = getRestField;
exports.getRestFields = getRestFields;
exports.registerRestField = void 0;
var _hooks = require("@wordpress/hooks");
var _lodash = require("lodash");
/* eslint no-console: [ 'error', { allow: [ 'error' ] } ] */

/**
 * WordPress dependencies
 */

/**
 * External dependencies
 */

/**
 * Rest fields definitions keyed by rest field name.
 *
 */
const restFields = {};

/**
 * Register rest fields
 *
 * @param {string} name     Rest field unique name. Must be unique.
 * @param {Object} settings Rest field settings.
 *
 * @example
 * registerRestField('rest-field-example', {
 *    getValue: (select) => select('my-example-store').myExampleSelector();
 * })
 */
const registerRestField = (name, settings) => {
  if (typeof name !== 'string') {
    console.error('Rest field key must be string.');
    return;
  }
  if (!settings.selectValue) {
    console.error('"selectValue" setting is missing!');
    return;
  }
  if (!(0, _lodash.isFunction)(settings.selectValue)) {
    console.error('The "selectValue" property must be a valid function.');
    return;
  }
  if (restFields[name]) {
    console.error(`Rest field "${name}" is already registered.`);
  }
  settings = (0, _hooks.applyFilters)('QuillForms.RestFields.RestFieldSettings', settings, name);
  restFields[name] = {
    ...settings
  };
  (0, _hooks.doAction)('QuillForms.RestFields.RestFieldRegistered', settings, name);
  return settings;
};

/**
 * Returns a registered rest field settings.
 *
 * @param {string} name Rest field name.
 *
 */
exports.registerRestField = registerRestField;
function getRestField(name) {
  return restFields[name];
}

/**
 * Returns all registered rest fields.
 */
function getRestFields() {
  return restFields;
}
//# sourceMappingURL=index.js.map